import{I as y}from"./ItemsListing-BNJg2MyK.js";import{x as f,r as i,H as m,o as v,I as e,ag as r,b,y as h,z as I,M as p,aj as l}from"./index-DJHitrKX.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_9ca321c3_lang-_lsFI5rQ.js";import"./ProviderIcon.vue_vue_type_script_setup_true_lang-CNlAq-jT.js";import"./VListItem-12Wt-HBF.js";import"./VChip-ClDFnVJT.js";import"./VList-BX74mk0S.js";import"./VCardText-8kU2RnWJ.js";import"./VCard-CTh4pnjm.js";import"./VMenu-iVz4cckD.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-DOz6X9XT.js";import"./VCheckbox-3aIL0vaW.js";import"./VCheckboxBtn-dAENQuo8.js";import"./VTooltip-CC0Yfw6u.js";import"./VSpacer-C1vP4eYJ.js";/* empty css              */import"./PanelviewItemCompact-UEfnScEJ.js";import"./Container-DzCq22Wj.js";import"./VContainer-BVnHxF_6.js";import"./Toolbar-DsD0yISu.js";import"./VToolbar-5UlLOvbM.js";import"./VTextField-B3QP6rDq.js";import"./VInfiniteScroll-CN_ha1Dt.js";import"./layout-DuzBpUJc.js";import"./VRow-B5X4VCpx.js";import"./VVirtualScroll-2KPgq6zI.js";import"./VAlert-DIuxfh9u.js";const V=f({name:"Podcasts",__name:"LibraryPodcasts",setup(w){const a=i(!1),s=i(m.libraryPodcastsCount),d=i([]),c=["name","name_desc","sort_name","sort_name_desc","timestamp_added","timestamp_added_desc","timestamp_modified","timestamp_modified_desc","last_played","last_played_desc","play_count","play_count_desc"],u=async function(t){if(t.refresh&&!a.value){for(e.startSync([p.PLAYLIST]),await l(250);e.syncTasks.value.length>0&&e.syncTasks.value.filter(o=>o.media_types.includes(p.PLAYLIST)).length!=0;)await l(500);await l(500)}return a.value=!1,_(t),await e.getLibraryPodcasts(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy)},_=async function(t){if(!t.favoritesOnly){s.value=m.libraryPodcastsCount;return}s.value=await e.getLibraryPodcastsCount(t.favoritesOnly||!1)};return v(()=>{const t=e.subscribe_multi([r.MEDIA_ITEM_ADDED,r.MEDIA_ITEM_UPDATED,r.MEDIA_ITEM_DELETED],o=>{var n;(n=o.object_id)!=null&&n.startsWith("library://podcast")&&(a.value=!0)});b(t)}),(t,o)=>(h(),I(y,{itemtype:"podcasts",path:"librarypodcasts","show-duration":!1,"show-provider":!0,"show-favorites-only-filter":!0,"load-paged-data":u,"show-library":!0,"sort-keys":c,"update-available":a.value,title:t.$t("podcasts"),"allow-key-hooks":!0,"show-search-button":!0,"extra-menu-items":d.value,icon:"mdi-podcast","restore-state":!0,total:s.value},null,8,["update-available","title","extra-menu-items","total"]))}});export{V as default};
