import{x as s,ae as m,c as n,R as e,y as l,D as c,n as u,I as f}from"./index-DJHitrKX.js";import{I as h}from"./ItemsListing-BNJg2MyK.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_9ca321c3_lang-_lsFI5rQ.js";import"./ProviderIcon.vue_vue_type_script_setup_true_lang-CNlAq-jT.js";import"./VListItem-12Wt-HBF.js";import"./VChip-ClDFnVJT.js";import"./VList-BX74mk0S.js";import"./VCardText-8kU2RnWJ.js";import"./VCard-CTh4pnjm.js";import"./VMenu-iVz4cckD.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-DOz6X9XT.js";import"./VCheckbox-3aIL0vaW.js";import"./VCheckboxBtn-dAENQuo8.js";import"./VTooltip-CC0Yfw6u.js";import"./VSpacer-C1vP4eYJ.js";/* empty css              */import"./PanelviewItemCompact-UEfnScEJ.js";import"./Container-DzCq22Wj.js";import"./VContainer-BVnHxF_6.js";import"./Toolbar-DsD0yISu.js";import"./VToolbar-5UlLOvbM.js";import"./VTextField-B3QP6rDq.js";import"./VInfiniteScroll-CN_ha1Dt.js";import"./layout-DuzBpUJc.js";import"./VRow-B5X4VCpx.js";import"./VVirtualScroll-2KPgq6zI.js";import"./VAlert-DIuxfh9u.js";const Q=s({__name:"BrowseView",props:{path:{}},setup(i){const t=i,{t:o}=m(),p=n(()=>!t.path||t.path=="root"?o("browse"):e("bp6")?o("browse")+" | "+t.path:e("bp3")?t.path:o("browse")),a=async function(r){return await f.browse(t.path)};return(r,w)=>(l(),c("section",null,[u(h,{itemtype:"browse","show-provider":!1,"show-library":!1,"show-favorites-only-filter":!1,"show-track-number":!1,"load-items":a,"sort-keys":["original","name","name_desc"],title:p.value,path:r.path,"allow-key-hooks":!0,icon:"mdi-folder-outline"},null,8,["title","path"])]))}});export{Q as default};
