import{I as d}from"./ItemsListing-BNJg2MyK.js";import{x as _,r as m,H as n,o as b,I as e,ag as r,b as f,y as v,z as h,M as u,aj as s}from"./index-DJHitrKX.js";import"./ItemContextMenu.vue_vue_type_style_index_0_scoped_9ca321c3_lang-_lsFI5rQ.js";import"./ProviderIcon.vue_vue_type_script_setup_true_lang-CNlAq-jT.js";import"./VListItem-12Wt-HBF.js";import"./VChip-ClDFnVJT.js";import"./VList-BX74mk0S.js";import"./VCardText-8kU2RnWJ.js";import"./VCard-CTh4pnjm.js";import"./VMenu-iVz4cckD.js";import"./_plugin-vue_export-helper-DlAUqK2U.js";import"./eventbus-CGRXT3Tn.js";import"./ListItem-DOz6X9XT.js";import"./VCheckbox-3aIL0vaW.js";import"./VCheckboxBtn-dAENQuo8.js";import"./VTooltip-CC0Yfw6u.js";import"./VSpacer-C1vP4eYJ.js";/* empty css              */import"./PanelviewItemCompact-UEfnScEJ.js";import"./Container-DzCq22Wj.js";import"./VContainer-BVnHxF_6.js";import"./Toolbar-DsD0yISu.js";import"./VToolbar-5UlLOvbM.js";import"./VTextField-B3QP6rDq.js";import"./VInfiniteScroll-CN_ha1Dt.js";import"./layout-DuzBpUJc.js";import"./VRow-B5X4VCpx.js";import"./VVirtualScroll-2KPgq6zI.js";import"./VAlert-DIuxfh9u.js";const V=_({name:"Albums",__name:"LibraryAlbums",setup(A){const o=m(!1),i=m(n.libraryAlbumsCount),p=["name","name_desc","sort_name","sort_name_desc","year","year_desc","timestamp_added","timestamp_added_desc","last_played","last_played_desc","play_count","play_count_desc","artist_name","artist_name_desc"];b(()=>{const t=e.subscribe_multi([r.MEDIA_ITEM_ADDED,r.MEDIA_ITEM_UPDATED,r.MEDIA_ITEM_DELETED],a=>{var l;(l=a.object_id)!=null&&l.startsWith("library://artist")&&(o.value=!0)});f(t)});const c=async function(t){if(t.refresh){for(e.startSync([u.ALBUM]),await s(250);e.syncTasks.value.length>0&&e.syncTasks.value.filter(a=>a.media_types.includes(u.ALBUM)).length!=0;)await s(500);await s(500)}return o.value=!1,y(t),await e.getLibraryAlbums(t.favoritesOnly||void 0,t.search,t.limit,t.offset,t.sortBy,t.albumType)},y=async function(t){if(!t.favoritesOnly&&!t.albumType){i.value=n.libraryAlbumsCount;return}i.value=await e.getLibraryAlbumsCount(t.favoritesOnly||void 0,t.albumType||void 0)};return(t,a)=>(v(),h(d,{itemtype:"albums",path:"libraryalbums","show-provider":!1,"show-favorites-only-filter":!0,"load-paged-data":c,"sort-keys":p,"update-available":o.value,title:t.$t("albums"),"allow-key-hooks":!0,"show-search-button":!0,icon:"mdi-album","restore-state":!0,total:i.value,"show-album-type-filter":!0},null,8,["update-available","title","total"]))}});export{V as default};
